#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.14.0
%define plugin datetime
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        0.8.3
Release:        bp156.2.5
Summary:        Date And Time Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-datetime-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/0.8/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
# uses exo-open
Requires:       exo-tools
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The date and time plugin displays the current date and time on the panel and
can open a calendar when clicked.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libdatetime.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS THANKS
%license COPYING
%{_libdir}/xfce4/panel/plugins/libdatetime.so
%{_datadir}/xfce4/panel/plugins/datetime.desktop

%files lang -f %{name}.lang

%changelog
* Sat Jan 21 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.3
  * Translation Updates
* Mon Sep 26 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.2
  * Fix time calculation
  * build: Fix intltool lock file problem during make distcheck
  * Fix compilation warnings
  * autoconf: AM_CONFIG_HEADER -> AC_CONFIG_HEADERS
  * Update `.gitignore`
  * datetime: replace deprecated GTimeVal
  * Translation Updates
* Fri Dec 25 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.1
  * Fix build with panel 4.15
  * Update configure.ac.in syntax and enable debug when building from git
  * Remove GSourceFunc casts
  * Fix font size (gxo#panel-plugins/xfce4-datetime-plugin#30)
  * Add new README.md and update AM_INIT_AUTOMAKE
  * Add basic GitLab pipeline
  * Update URLs from goodies.x.o to docs.x.o (bxo#16159)
  * s/http/https
  * Update .gitignore
  * Make build less verbose
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.8.0
  * Translation updates
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omit Changelog
* Tue Apr 30 2019 maurizio.galli@gmail.com
- Update to version 0.7.1
  * Removed the frame around the calendar popup to simplify appearance
  * Spacing improvements in the preferences dialog (bxo#14662)
  * Fixed build warnings
  * Updated translations
* Tue Oct  3 2017 jengelh@inai.de
- Remove redundant %%clean section.
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to version 0.7
  port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
* Fri Feb 15 2013 gber@opensuse.org
- update to version 0.6.2
  - port to libxfce4ui
  - set text orientation depending on panel mode/orientation
  - translation updates
- remove obsolete xfce4-datetime-plugin-0.6.1-enable-tooltips.patch
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Sun Apr 15 2012 gber@opensuse.org
- recommend -lang subpackage
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Thu Oct 20 2011 gber@opensuse.org
- do not package .la file
* Fri Oct 14 2011 gber@opensuse.org
- added xfce4-datetime-plugin-0.6.1-enable-tooltips.patch which
  re-enables tooltip support (backported from upstream git)
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
